# Django Celery Lite - Lite version for Django Celery

[![Downloads](https://img.shields.io/travis/shinznatkid/django-celery-lite.svg)](https://travis-ci.org/shinznatkid/django-celery-lite/)
[![Downloads](https://img.shields.io/pypi/dm/django-celery-lite.svg)](https://pypi.python.org/pypi/django-celery-lite/)
[![Downloads](https://img.shields.io/pypi/v/django-celery-lite.svg)](https://pypi.python.org/pypi/django-celery-lite/)
[![Downloads](https://img.shields.io/badge/license-MIT-blue.svg)](https://pypi.python.org/pypi/django-celery-lite/)

Django Celery Lite is celery ingration Django just only command

Test Support Django >= 2.2.x

## Installation

1. Python package

        pip install django-celery-lite

2. Add 'djcelerylite' to INSTALLED_APPS:

        'djcelerylite',


## Usage

| Program       | Replace with                   |
|---------------|--------------------------------|
| `celery`        | `python manage.py celery`        |
| `celery worker` | `python manage.py celery worker` |
